# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_runners_response import ActionRunnersResponse

class TestActionRunnersResponse(unittest.TestCase):
    """ActionRunnersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionRunnersResponse:
        """Test ActionRunnersResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionRunnersResponse`
        """
        model = ActionRunnersResponse()
        if include_optional:
            return ActionRunnersResponse(
                runners = [
                    py_gitea_opensuse_org.models.action_runner.ActionRunner(
                        busy = True, 
                        ephemeral = True, 
                        id = 56, 
                        labels = [
                            py_gitea_opensuse_org.models.action_runner_label.ActionRunnerLabel(
                                id = 56, 
                                name = '', 
                                type = '', )
                            ], 
                        name = '', 
                        status = '', )
                    ],
                total_count = 56
            )
        else:
            return ActionRunnersResponse(
        )
        """

    def testActionRunnersResponse(self):
        """Test ActionRunnersResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
