# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.create_action_workflow_dispatch import CreateActionWorkflowDispatch

class TestCreateActionWorkflowDispatch(unittest.TestCase):
    """CreateActionWorkflowDispatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateActionWorkflowDispatch:
        """Test CreateActionWorkflowDispatch
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateActionWorkflowDispatch`
        """
        model = CreateActionWorkflowDispatch()
        if include_optional:
            return CreateActionWorkflowDispatch(
                inputs = {
                    'key' : ''
                    },
                ref = 'refs/heads/main'
            )
        else:
            return CreateActionWorkflowDispatch(
                ref = 'refs/heads/main',
        )
        """

    def testCreateActionWorkflowDispatch(self):
        """Test CreateActionWorkflowDispatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
