# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.payload_commit import PayloadCommit  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestPayloadCommit(unittest.TestCase):
    """PayloadCommit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PayloadCommit
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PayloadCommit`
        """
        model = py_gitea_opensuse_org.models.payload_commit.PayloadCommit()  # noqa: E501
        if include_optional :
            return PayloadCommit(
                added = [
                    ''
                    ], 
                author = py_gitea_opensuse_org.models.payload_user.PayloadUser(
                    email = '', 
                    name = '', 
                    username = '', ), 
                committer = py_gitea_opensuse_org.models.payload_user.PayloadUser(
                    email = '', 
                    name = '', 
                    username = '', ), 
                id = '', 
                message = '', 
                modified = [
                    ''
                    ], 
                removed = [
                    ''
                    ], 
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                url = '', 
                verification = py_gitea_opensuse_org.models.payload_commit_verification.PayloadCommitVerification(
                    payload = '', 
                    reason = '', 
                    signature = '', 
                    signer = py_gitea_opensuse_org.models.payload_user.PayloadUser(
                        email = '', 
                        name = '', 
                        username = '', ), 
                    verified = True, )
            )
        else :
            return PayloadCommit(
        )
        """

    def testPayloadCommit(self):
        """Test PayloadCommit"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
